# Getestet mit Python 3.11.6 und PySide 6.6.0

import math
import PySide6.QtWidgets as widgets
import PySide6.QtCore as core
import PySide6.QtGui as gui

class MeinWidget(widgets.QWidget):
    def __init__(self, parent : widgets.QWidget|None = None):
        super().__init__(parent)
        self.setAttribute(core.Qt.WidgetAttribute.WA_TransparentForMouseEvents) # Damit die Mausaktionen beim Browser unten drunter ankommen
        self._track : list[tuple[float, float, float]] = []

    def appendToTrack(self, p: tuple[float, float, float]):
        self._track.append(p)
        self.update()

    def paintEvent(self, event: gui.QPaintEvent) -> None:
        super().paintEvent(event)
        painter = gui.QPainter(self)
        br = gui.QBrush()
        br.setStyle(core.Qt.BrushStyle.SolidPattern)
        pn = gui.QPen()
        for i in range(len(self._track)-1):
            (x, y, t) = self._track[i]
            (x1, y1, t1) = self._track[i + 1]
            dt = t1 - t
            v = math.sqrt((x1-x)**2 + (y1-y)**2)/(dt + 0.00001)
            if v > 2000.0:
                pn.setColor(gui.QColor(0, 0, 255, 128))
                painter.setPen(pn)
                painter.drawLine(core.QPointF(x, y), core.QPointF(x1, y1))
            else:
                alpha = int(255 / 2 * dt)
                if alpha > 255:
                    alpha = 255
                br.setColor(gui.QColor(255, 120, 120, alpha))
                painter.setBrush(br)
                pn.setColor(core.Qt.GlobalColor.transparent)
                painter.setPen(pn)
                painter.drawEllipse(core.QPointF(x-40, y-40), 80, 80)
        painter.end()
